# coding: utf-8

"""
    IONOS Cloud - DNS API

    Cloud DNS service helps IONOS Cloud customers to automate DNS Zone and Record management. 

    The version of the OpenAPI document: 1.17.0
    Contact: support@cloud.ionos.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NsecMode(str, Enum):
    """
    NSEC mode. 
    """

    """
    allowed enum values
    """
    NSEC = 'NSEC'
    NSEC3 = 'NSEC3'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NsecMode from a JSON string"""
        return cls(json.loads(json_str))


