# coding: utf-8

# flake8: noqa

"""
    IONOS Cloud - DNS API

    Cloud DNS service helps IONOS Cloud customers to automate DNS Zone and Record management. 

    The version of the OpenAPI document: 1.17.0
    Contact: support@cloud.ionos.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "2.0.0-beta.1"

# import apis into sdk package
from ionoscloud_dns.api.dnssec_api import DNSSECApi
from ionoscloud_dns.api.quota_api import QuotaApi
from ionoscloud_dns.api.records_api import RecordsApi
from ionoscloud_dns.api.reverse_records_api import ReverseRecordsApi
from ionoscloud_dns.api.secondary_zones_api import SecondaryZonesApi
from ionoscloud_dns.api.zone_files_api import ZoneFilesApi
from ionoscloud_dns.api.zones_api import ZonesApi

# import ApiClient
from ionoscloud_dns.api_response import ApiResponse
from ionoscloud_dns.api_client import ApiClient
from ionoscloud_dns.configuration import Configuration
from ionoscloud_dns.exceptions import OpenApiException
from ionoscloud_dns.exceptions import ApiTypeError
from ionoscloud_dns.exceptions import ApiValueError
from ionoscloud_dns.exceptions import ApiKeyError
from ionoscloud_dns.exceptions import ApiAttributeError
from ionoscloud_dns.exceptions import ApiException

# import models into sdk package
from ionoscloud_dns.models.algorithm import Algorithm
from ionoscloud_dns.models.common_zone import CommonZone
from ionoscloud_dns.models.common_zone_read import CommonZoneRead
from ionoscloud_dns.models.common_zone_read_list import CommonZoneReadList
from ionoscloud_dns.models.dnssec_key import DnssecKey
from ionoscloud_dns.models.dnssec_key_create import DnssecKeyCreate
from ionoscloud_dns.models.dnssec_key_parameters import DnssecKeyParameters
from ionoscloud_dns.models.dnssec_key_read_creation import DnssecKeyReadCreation
from ionoscloud_dns.models.dnssec_key_read_list import DnssecKeyReadList
from ionoscloud_dns.models.dnssec_key_read_list_metadata import DnssecKeyReadListMetadata
from ionoscloud_dns.models.dnssec_key_read_list_properties import DnssecKeyReadListProperties
from ionoscloud_dns.models.dnssec_key_read_list_properties_key_parameters import DnssecKeyReadListPropertiesKeyParameters
from ionoscloud_dns.models.dnssec_key_read_list_properties_nsec_parameters import DnssecKeyReadListPropertiesNsecParameters
from ionoscloud_dns.models.error import Error
from ionoscloud_dns.models.error_messages_inner import ErrorMessagesInner
from ionoscloud_dns.models.key_data import KeyData
from ionoscloud_dns.models.key_parameters import KeyParameters
from ionoscloud_dns.models.ksk_bits import KskBits
from ionoscloud_dns.models.links import Links
from ionoscloud_dns.models.metadata import Metadata
from ionoscloud_dns.models.metadata_for_secondary_zone_records import MetadataForSecondaryZoneRecords
from ionoscloud_dns.models.metadata_with_state_fqdn_zone_id import MetadataWithStateFqdnZoneId
from ionoscloud_dns.models.metadata_with_state_nameservers import MetadataWithStateNameservers
from ionoscloud_dns.models.nsec_mode import NsecMode
from ionoscloud_dns.models.nsec_parameters import NsecParameters
from ionoscloud_dns.models.provisioning_state import ProvisioningState
from ionoscloud_dns.models.quota import Quota
from ionoscloud_dns.models.quota_detail import QuotaDetail
from ionoscloud_dns.models.record import Record
from ionoscloud_dns.models.record_create import RecordCreate
from ionoscloud_dns.models.record_ensure import RecordEnsure
from ionoscloud_dns.models.record_read import RecordRead
from ionoscloud_dns.models.record_read_list import RecordReadList
from ionoscloud_dns.models.record_type import RecordType
from ionoscloud_dns.models.reverse_record import ReverseRecord
from ionoscloud_dns.models.reverse_record_create import ReverseRecordCreate
from ionoscloud_dns.models.reverse_record_ensure import ReverseRecordEnsure
from ionoscloud_dns.models.reverse_record_read import ReverseRecordRead
from ionoscloud_dns.models.reverse_records_read_list import ReverseRecordsReadList
from ionoscloud_dns.models.secondary_zone import SecondaryZone
from ionoscloud_dns.models.secondary_zone_create import SecondaryZoneCreate
from ionoscloud_dns.models.secondary_zone_ensure import SecondaryZoneEnsure
from ionoscloud_dns.models.secondary_zone_read import SecondaryZoneRead
from ionoscloud_dns.models.secondary_zone_read_list import SecondaryZoneReadList
from ionoscloud_dns.models.secondary_zone_record_read import SecondaryZoneRecordRead
from ionoscloud_dns.models.secondary_zone_record_read_list import SecondaryZoneRecordReadList
from ionoscloud_dns.models.secondary_zone_record_read_list_metadata import SecondaryZoneRecordReadListMetadata
from ionoscloud_dns.models.zone import Zone
from ionoscloud_dns.models.zone_create import ZoneCreate
from ionoscloud_dns.models.zone_ensure import ZoneEnsure
from ionoscloud_dns.models.zone_read import ZoneRead
from ionoscloud_dns.models.zone_read_list import ZoneReadList
from ionoscloud_dns.models.zone_transfer_primary_ip_status import ZoneTransferPrimaryIpStatus
from ionoscloud_dns.models.zone_transfer_primary_ips_status import ZoneTransferPrimaryIpsStatus
from ionoscloud_dns.models.zsk_bits import ZskBits
