# coding: utf-8

"""
    IONOS Cloud - DNS API

    Cloud DNS service helps IONOS Cloud customers to automate DNS Zone and Record management. 

    The version of the OpenAPI document: 1.17.0
    Contact: support@cloud.ionos.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class RecordType(str, Enum):
    """
    Holds supported DNS resource record types. In the DNS context a record is a DNS resource record.
    """

    """
    allowed enum values
    """
    A = 'A'
    AAAA = 'AAAA'
    CNAME = 'CNAME'
    ALIAS = 'ALIAS'
    MX = 'MX'
    NS = 'NS'
    SRV = 'SRV'
    TXT = 'TXT'
    CAA = 'CAA'
    SSHFP = 'SSHFP'
    TLSA = 'TLSA'
    SMIMEA = 'SMIMEA'
    DS = 'DS'
    HTTPS = 'HTTPS'
    SVCB = 'SVCB'
    OPENPGPKEY = 'OPENPGPKEY'
    CERT = 'CERT'
    URI = 'URI'
    RP = 'RP'
    LOC = 'LOC'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of RecordType from a JSON string"""
        return cls(json.loads(json_str))


